//
//  AWFMKTileSource.h
//  AerisMap
//
//  Created by Nicholas Shipes on 5/21/14.
//  Copyright (c) 2014 AerisWeather, LLC. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <AerisMapKit/AWFTileSource.h>
#import <AerisMapKit/AWFOverlayProvider.h>
#import <AerisMapKit/AWFAmpTileSource.h>

NS_ASSUME_NONNULL_BEGIN

FOUNDATION_EXPORT NSString * const AWFMKTileSourceNeedsRedraw;

/**
 The `AWFMKTileProvider` protocol defines the properties required by overlay sources rendered on an `MKMapView` instance.
 */
@protocol AWFMKTileProvider <NSObject>

/**
 The `MKTileOverlay` instance managed by the layer.
 */
@property (readonly, nonatomic, strong) id<MKOverlay> overlay;

/**
 The position of the overlay relative to other content on the map.
 */
@property (nonatomic, assign) MKOverlayLevel overlayLevel;

/**
 The amount of transparency to apply to the overlay.
 */
@property (nonatomic, assign) CGFloat alpha;

@end

/**
 An `AWFMKTileSource` object is a subclass of `AWFTileSource` that provides the necessary `MKOverlay` instance to use with Apple's MapKit 
 for displaying a tile overlay on an `MKMapView` instance.
 */
@interface AWFMKTileSource : AWFTileSource <AWFOverlayProvider, AWFMKTileProvider>

/**
 The `MKTileOverlay` instance managed by the layer.
 */
@property (readonly, nonatomic, strong) id<MKOverlay> overlay;

/**
 The position of the overlay relative to other content on the map.
 */
@property (nonatomic, assign) MKOverlayLevel overlayLevel;

@end

NS_ASSUME_NONNULL_END
