//
//  AWFMapboxMapStrategy.h
//  AerisMapboxMap
//
//  Created by Nicholas Shipes on 7/2/15.
//  Copyright (c) 2015 AerisWeather, LLC. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <AerisMapKit/AerisMapKit.h>
#import <Mapbox/Mapbox.h>

NS_ASSUME_NONNULL_BEGIN

/**
 *  An `AWFMapboxMapStrategy` object implements the `AWFMapStrategy` protocol and provides the necessary functionality for managing a `AWFWeatherMap` configured
 *  with an `MGLMapView` instance and Mapbox base map.
 */
@interface AWFMapboxMapStrategy : NSObject <AWFMapStrategy, MGLMapViewDelegate>

/**
 The map strategy type for the instance.
 */
@property (readonly, nonatomic) AWFMapStrategyType strategyType;

/**
 The map view being managed by the strategy.
 */
@property (nonatomic, strong) MGLMapView *mapView;

/**
 The weather map configuration associated with the weather map.
 */
@property (readonly, nonatomic, strong) AWFWeatherMapConfig *config;

/**
 The factory object responsible for generating the map overlays and annotations required by `MKMapView`.
 */
@property (readonly, nonatomic, strong) id<AWFMapOverlayFactory> overlayFactory;

/**
 The annotation callout view used when selecting annotations.
 */
@property (readonly, nonatomic, strong) AWFMapCallout *callout;

/**
 The complete list of overlays associated with the map view.
 */
@property (nonatomic, strong, readonly) NSArray *overlays;

/**
 The complete list of annotations associated with the map view.
 */
@property (nonatomic, strong, readonly) NSArray *annotations;

/**
 The visible map coordinate bounds of the internal map view.
 */
@property (nonatomic, readonly) AWFMapCoordinateBounds *coordinateBounds;

/**
 The map coordinate at the center of the internal map view.
 */
@property (nonatomic, readonly) CLLocationCoordinate2D centerCoordinate;

/**
 The zoom level of the internal map view.
 */
@property (nonatomic, readonly) NSInteger zoomLevel;

/**
 The internal view used for rendering animated raster data.
 */
@property (readonly, nonatomic, strong) UIView *animationContainerView;

/**
 *  The receiver's delegate.
 *
 *	The delegate should implement the methods of the `AWFMapStrategyDelegate` protocol.
 */
@property (nonatomic, weak) id<AWFMapStrategyDelegate> delegate;

/**
 Returns the default annotation view for the specified annotation as configured and styled by the SDK.

 @param annotation Annotation to return the default MKAnnotationView for
 */
- (MGLAnnotationView *)defaultAnnotationViewForAnnotation:(id<MGLAnnotation>)annotation;

- (id)defaultRendererForOverlay:(id)overlay NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
