Pod::Spec.new do |s|
  s.name         = 'AerisWeather'
  s.version      = '3.4.1'
  s.summary      = 'Quickly integrate AerisWeather API data and AerisWeather Mapping Platform imagery into your iOS apps.'
  s.description  = <<-DESC
                      The AerisWeather SDK for iOS allows a developer to quickly and easily add weather content and functionality to their iOS applications quickly and easily without having to code anything themselves. It utilizes the AerisWeather API and AerisWeather Mapping Platform backend for data loading and is built on top of an object mapping system that efficiently loads requested weather content into third-party iOS applications, greatly reducing the amount of code and development needed on the developer end.
                    DESC
  s.readme = "https://raw.githubusercontent.com/aerisweather/Aeris-iOS-Library/#{s.version.to_s}/README.md"

  s.homepage     = 'https://github.com/aerisweather/Aeris-iOS-Library'
  s.documentation_url = 'http://www.aerisweather.com/support/docs/toolkits/aeris-ios-sdk/'
  s.social_media_url = 'https://twitter.com/AerisWeather'
  s.license      = { :type => 'BSD', :file => 'LICENSE.md' }
  s.author       = { 'AerisWeather, LLC' => 'http://aerisweather.com' }
  s.source       = {
    :http => "https://cdn.aerisapi.com/sdk/ios/builds/aerisweather-ios-sdk-#{s.version.to_s}.zip",
    :flatten => true
  }

  s.platforms = { :ios => '11.0', :tvos => '11.0' }
  s.requires_arc = true
  s.default_subspecs = 'Data'

  s.subspec 'Core' do |ss|
    ss.header_dir = 'AerisCore'
    ss.vendored_frameworks = 'AerisCore.xcframework'
    ss.framework = 'Foundation'
  end

  s.subspec 'CoreUI' do |ss|
    ss.header_dir = 'AerisCoreUI'
    ss.vendored_frameworks = 'AerisCoreUI.xcframework'
    ss.framework = 'UIKit'
    ss.dependency 'AerisWeather/Core'
  end

  s.subspec 'Data' do |ss|
    ss.header_dir = 'AerisWeatherKit'
    ss.vendored_frameworks = 'AerisWeatherKit.xcframework'
    ss.dependency 'AerisWeather/CoreUI'
  end

  s.subspec 'Maps' do |ss|
    ss.header_dir = 'AerisMapKit'
    ss.vendored_frameworks = 'AerisMapKit.xcframework'
    ss.framework = 'MapKit'
    ss.dependency 'AerisWeather/Data'
  end

  s.subspec 'Mapbox' do |ss|
    ss.header_dir = 'AerisMapboxMapKit'
    ss.vendored_frameworks = 'AerisMapboxMapKit.xcframework'
    ss.dependency 'Mapbox-iOS-SDK'
    ss.dependency 'AerisWeather/Maps'
    ss.platforms = { :ios => '11.0' }
  end

  s.subspec 'Google' do |ss|
    ss.preserve_paths = '**'
    ss.header_dir = 'AerisGoogleMapKit'
    ss.vendored_frameworks = 'AerisGoogleMapKit.xcframework'
    ss.dependency 'GoogleMaps'
    ss.dependency 'AerisWeather/Maps'
    ss.platforms = { :ios => '11.0' }
  end

end
